using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using DG.Tweening;

public class AnimController : MonoBehaviour {

    public SpriteAnimator.Anim idle;
    public SpriteAnimator.Anim idleUp;
    public SpriteAnimator.Anim moving;
    public SpriteAnimator.Anim movingUp;

    public Player.State animState = Player.State.None;

    private SpriteRenderer sr;
    private Player player;
    private SpriteAnimator spriteAnimator;
    public bool animUp = false;

    private void Awake() {
        sr = GetComponent<SpriteRenderer>();
        player = GetComponentInParent<Player>();
        spriteAnimator = GetComponent<SpriteAnimator>();
        player.digController.OnDigAction += OnDigAction;
    }

    void OnDigAction() {
        //sr.transform.DOShakePosition(0.2f, 0.1f, 40, 90);
        sr.transform.DOShakeRotation(0.4f, 10f, 15, 90);
    }

    // Update is called once per frame
    void LateUpdate() {
        bool playerUp = player.direction.y > 0 && player.state == Player.State.Moving;
        if (player.state != animState || animUp != playerUp) {
            animState = player.state;
            switch (player.state) {
                case Player.State.None:
                    break;
                case Player.State.Idle:
                        spriteAnimator.SetAnim(idle);
                    break;
                case Player.State.Moving: if (playerUp) {
                        spriteAnimator.SetAnim(movingUp);
                    } else {
                        spriteAnimator.SetAnim(moving);
                    }
                    break;
                case Player.State.Digging:
                    spriteAnimator.SetAnim(idle);
                    break;
                case Player.State.Jumping:
                    spriteAnimator.SetAnim(moving);
                    break;
            }

            if (player.state == Player.State.Digging || player.state == Player.State.Jumping) {
                sr.maskInteraction = SpriteMaskInteraction.VisibleOutsideMask;
            } else {
                sr.maskInteraction = SpriteMaskInteraction.None;
            }
        }


        sr.flipX = player.direction.x < 0;
        animUp = playerUp;
    }


}
