using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using DG.Tweening;

public class Arrow : MonoBehaviour {
    public Sprite[] sprites;
    public SpriteRenderer sr;

    public bool liveUpdate = false;

    //private void Update() {
    //    if (liveUpdate) Setup();
    //}

    private Vector2Int eggCell;

    public void Setup() {
        Vector2Int closestUndugEgg = Vector2Int.zero;

        float closestDistance = float.MaxValue;
        foreach (var cellEntry in Map.instance.GetCells()) {
            if (cellEntry.Value.egg && !cellEntry.Value.dug) {
                Vector3 eggPos = Map.instance.grid.GetCellCenterWorld(cellEntry.Key.ToVector3());
                float dist = Vector2.Distance(eggPos, transform.position);

                if (dist < closestDistance) {
                    closestDistance = dist;
                    closestUndugEgg = cellEntry.Key;
                }
            }
        }

        eggCell = closestUndugEgg;
        Vector3 closestUndugEggWorldPos = Map.instance.grid.GetCellCenterWorld(closestUndugEgg.ToVector3());
        Vector3 dirToEgg = (closestUndugEggWorldPos - transform.position).normalized;
        float angleToClosest = Vector3.SignedAngle(Vector3.up, dirToEgg, Vector3.forward);

        angleToClosest += 180;

        int spriteIndex = Mathf.RoundToInt(angleToClosest / 45);
        if (spriteIndex >= sprites.Length) {
            spriteIndex = 0;
        }

        sr.sprite = sprites[spriteIndex];
        sr.maskInteraction = SpriteMaskInteraction.VisibleOutsideMask;

        Animate();

        Map.instance.OnHoleDug += Map_OnHoleDug;
    }

    private void Map_OnHoleDug(Vector3Int cellPos) {
        if (cellPos.ToVector2() == eggCell) {
            Hide();
        }
    }

    private void Hide() {
        sr.transform.DOScale(0f, 0.25f).SetDelay(Random.Range(0.1f, 0.5f));
    }

    private void Animate() {
        sr.transform.localPosition = Vector3.down * 1;
        sr.transform.DOLocalMoveY(0, 0.25f).OnComplete(() => sr.maskInteraction = SpriteMaskInteraction.None);
    }
}
