using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class DigController : MonoBehaviour
{
    public System.Action OnDigAction;

    public Player player;
    public float value = 0;
    public int direction = 1;
    public bool stopped = false;
    private float stoppedTimer = 0;
    public bool digFinished = false;
    public DigPanel panel;

    private void Awake() {
        player = GetComponentInParent<Player>();
    }

    private void Update() {
        if (stopped) {
            stoppedTimer += Time.deltaTime;
            if (stoppedTimer >= player.ps.digStopDuration) {
                stopped = false;
            }
            return;
        }

        if (!digFinished && player.endDigProgress >= 1) {
            OnDigFinished();
        }


        value += Time.deltaTime * player.ps.digArrowSpeed * direction;

        if (value >= 1) {
            direction = -1;
            value = 1;
        } else if (value <= -1) {
            direction = 1;
            value = -1;
        }
    }

    public void StartDigging() {
        panel.Show();
        stopped = true;
        stoppedTimer = 0;
        digFinished = false;
    }

    public void OnAction() {
        if (stopped) return;
        if (digFinished) return;

        OnDigAction?.Invoke();

        stopped = true;
        stoppedTimer = 0;

        float absValue = Mathf.Abs(value);
        int category = GetCategory(absValue);
        float categorizedValue = GetCategorizedValue(category);

        player.AddDigProgress(categorizedValue * player.ps.digProgressMultiplier);

        panel.OnStoppedCategory(category);

        Sounds.Play(Sounds.instance.digClips, transform.position);
    }

    private int GetCategory(float v) {
        if (v < 9f / 90) return 0;
        if (v < 36f / 90) return 1;
        return 2;
    }

    private void OnDigFinished() {
        digFinished = true;
        panel.Hide();
    }

    private float GetCategorizedValue(int cat) {
        switch (cat) {
            case 0: return 1f;
            case 1: return 0.5f;
            case 2: return 0.25f;
        }
        return 0.25f;
    }
}
