using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using DG.Tweening;

public class DigPanel : MonoBehaviour
{
    public RectTransform arrow;
    public DigController digController;
    public Image fill;
    public Image underFill;
    public GameObject[] labels;
    public RectTransform labelsParent;

    private void Awake() {
        transform.localScale = Vector3.zero;
        labelsParent.localScale = Vector3.zero;
    }

    // Update is called once per frame
    void Update()
    {
        float angle = digController.value.Map(-1, 1, -90, 90);
        arrow.localRotation = Quaternion.AngleAxis(angle, Vector3.forward);

        if (digController.player.endDigProgress < 1f) {
            transform.position = digController.transform.position;
        }

        fill.fillAmount = digController.player.digProgress;
        underFill.fillAmount = digController.player.endDigProgress;
    }

    public void Show() {
        transform.localScale = Vector3.zero;
        transform.DOScale(1f, 0.3f).SetEase(Ease.OutBack);
        fill.fillAmount = 0;
        underFill.fillAmount = 0;
        Sounds.Play(Sounds.instance.indicatorAppear, transform.position);
    }

    public void Hide() {
        transform.DOScale(0f, 0.3f).SetEase(Ease.InBack);
        Sounds.Play(Sounds.instance.indicatorHide, transform.position);
    }

    // 0 best, 1 mid, 2 worst
    public void OnStoppedCategory(int cat) {
        if (cat == 0) {
            GetComponent<RectTransform>().DOShakePosition(0.4f, 10f, 20, 90f);
            Sounds.Play(Sounds.instance.perfect, transform.position);
        }
        
        if (cat == 1) {
            Sounds.Play(Sounds.instance.great, transform.position);
        }
        
        if (cat == 2) {
            Sounds.Play(Sounds.instance.good, transform.position);
        }

        for (int i = 0; i < 3; i++) {
            labels[i].SetActive(i == cat);
        }

        labelsParent.DOKill();
        labelsParent.localRotation = Quaternion.identity;
        labelsParent.DORotate(new Vector3(0, 0, Random.Range(-10, 10f)), 0.2f).SetEase(Ease.OutQuad);
        labelsParent.localScale = Vector3.zero;
        labelsParent.DOScale(1f, 0.2f).SetEase(Ease.OutElastic);
        labelsParent.localPosition = new Vector3(0, 163, 0);
        labelsParent.DOLocalMoveY(0f, 0.2f).SetDelay(0.4f).SetEase(Ease.OutQuad);
        labelsParent.DOScale(0f, 0.1f).SetDelay(0.45f);
    }
}
