using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using DG.Tweening;

public class Digglet : MonoBehaviour
{
    public SpriteAnimator spriteAnimator;
    private bool moving = false;
    private bool spawning = true;

    public SpriteAnimator.Anim animIdle;
    public SpriteAnimator.Anim animMoving;

    private Player player;
    private Transform target;
    private Rigidbody2D rb;
    private Vector2 direction;
    private SpriteRenderer sr;

    private Tween jumpTween = null;

    private void Awake() {
        rb = GetComponent<Rigidbody2D>();
        sr = spriteAnimator.GetComponent<SpriteRenderer>();
    }

    public void Setup(Player _player) {
        player = _player;
        target = player.GetTargetForDigglet();
        player.AddDigglet(this);

        spriteAnimator.SetAnim(animIdle);
        sr.transform.localScale = Vector3.zero;
        sr.sortingLayerName = "UI";
        sr.sortingOrder = 40;
        sr.transform.DOScale(1f, 0.25f);
        DOVirtual.DelayedCall(0.5f, () => spawning = false, false).OnComplete(() => {
            sr.sortingLayerName = "Default";
            sr.sortingOrder = 0;
        });
    }

    // Update is called once per frame
    void FixedUpdate() {
        if (target == null) return;
        if (spawning) return;

        bool wasMoving = moving;
        float distToTarget = Vector2.Distance(target.position.ToVector2(), rb.position);
        if (distToTarget <= player.ps.diggletDistance) {
            if (wasMoving) {
                moving = false;
                spriteAnimator.SetAnim(animIdle);
            }
            return;
        }

        if (!wasMoving) {
            moving = true;
            spriteAnimator.SetAnim(animMoving);
        }

        Vector2 toTarget = target.position.ToVector2() - rb.position;
        Vector2 moveVector = toTarget.normalized * player.ps.diggletSpeed * Time.fixedDeltaTime;
        direction = moveVector.normalized;
        sr.flipX = direction.x < 0;

        rb.MovePosition(rb.position + moveVector);

        if (jumpTween == null || !jumpTween.IsPlaying()) {
            jumpTween = sr.transform.DOLocalJump(Vector3.zero, 0.2f, 1, Random.Range(0.18f, 0.22f)).SetAutoKill(false);
        }
    }
}
