using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using DG.Tweening;

public class Egg : MonoBehaviour
{
    public Digglet diggletPrefab;
    public Transform visual;

    public SpriteRenderer partTop;
    public SpriteRenderer partBot;

    Player player;
    private float height = 0;

    public void Setup(Player _player) {
        player = _player;

        Spawn();
    }

    private void Update() {
        UpdateVisualHeight();
    }

    private void UpdateVisualHeight() {
        visual.localPosition = visual.localPosition.SetY(height);
    }

    private void Spawn() {
        transform.position = player.transform.position;
        height = player.visual.localPosition.y;
        UpdateVisualHeight();
        Sounds.Play(Sounds.instance.eggFlyOut, transform.position);
        Sequence seq = DOTween.Sequence()
        .Append(DOVirtual.Float(height, player.ps.jumpHeight, player.ps.jumpDurationUp, (f) => { height = f; }).SetEase(Ease.OutQuad))
        .Append(DOVirtual.Float(player.ps.jumpHeight, 0, player.ps.jumpDurationDown, (f) => { height = f; }).SetEase(Ease.InQuad))
        .OnComplete(OnLanded);

        Vector3 rng = Random.insideUnitCircle;
        rng /= rng.magnitude;
        rng *= 1.5f;
        transform.DOMove(transform.position + rng, player.ps.jumpDurationUp + player.ps.jumpDurationDown).SetEase(Ease.Linear);

        DOVirtual.DelayedCall(player.ps.jumpDurationUp + player.ps.jumpDurationDown - 0.1f, () => {
            TimescaleController.instance.timescale = 0.2f;
            DOVirtual.Float(0.2f, 1f, 0.4f, (f) => TimescaleController.instance.timescale = f).SetDelay(0.2f);
        });
    }

    private void OnLanded() {
        Digglet digglet = Instantiate(diggletPrefab, transform.position, Quaternion.identity);
        digglet.Setup(player);

        visual.gameObject.SetActive(false);
        partTop.gameObject.SetActive(true);
        partBot.gameObject.SetActive(true);
        partTop.transform.DOLocalJump(Vector3.left, 3f, 1, 1f);
        partBot.transform.DOLocalJump(Vector3.right, 3f, 1, 1f);
        partTop.DOFade(0f, 0.5f).SetDelay(0.5f);
        partBot.DOFade(0f, 0.5f).SetDelay(0.5f);
        partTop.transform.DOLocalRotate(Vector3.forward * 1000, 1f, RotateMode.FastBeyond360);
        partBot.transform.DOLocalRotate(Vector3.back * 1000, 1f, RotateMode.FastBeyond360);

        var fx = Instantiate(player.spawnVFX, transform.position, Quaternion.identity);
        CameraController.instance.Screenshake(0.6f);


    }
}
