using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Cell {
    public bool dug;
    public bool egg;
}

public class Map : MonoBehaviour {
    public Grid grid;

    static public Map instance;

    public System.Action<Vector3Int> OnHoleDug;

    public int NUM_EGGS = 30;
    public int MAP_SIZE = 20;

    public bool drawEggs = true;

    private Dictionary<Vector2Int, Cell> cells = new Dictionary<Vector2Int, Cell>();

    private void Awake() {
        instance = this;
    }

    public void Start() {
        SpawnEggs();
    }

    public Dictionary<Vector2Int, Cell> GetCells() {
        return cells;
    }

    public void SpawnEggs() {
        for (int i = 0; i < NUM_EGGS; i++) {
            Vector2Int pos = new Vector2Int(Random.Range(-MAP_SIZE, MAP_SIZE), Random.Range(-MAP_SIZE, MAP_SIZE));
            Cell cell = GetCell(pos);
            if (!cell.egg) {
                cell.egg = true;
            } else {
                i--;
            }
        }
    }

    public Cell GetCell(Vector2Int pos) {
        if (!cells.ContainsKey(pos)) {
            cells.Add(pos, new Cell());
        }

        return cells[pos];
    }

    public Cell GetCell(Vector3Int pos) {
        return GetCell(pos.ToVector2());
    }

    public Cell GetCellFromWorld(Vector3 pos) {
        return GetCell(GetClosestCell(pos));
    }

    public Vector3 GetClosestCellCenter(Vector3 worldPos) {
        Vector3Int cellPos = grid.WorldToCell(worldPos);
        return grid.GetCellCenterWorld(cellPos);
    }

    public Vector3Int GetClosestCell(Vector3 worldPos) {
        Vector3Int cellPos = grid.WorldToCell(worldPos);
        return cellPos;
    }

    // Update is called once per frame
    void Update() {
        if (Input.GetKeyDown(KeyCode.V)) {
            Vector3 playerPos = FindObjectOfType<Player>().transform.position;
            Debug.Log($"Player pos: {playerPos}, LocalToCell: {grid.LocalToCell(playerPos)}, {grid.WorldToCell(playerPos)}");
        }
    }

    private void OnDrawGizmos() {
        Gizmos.color = Color.cyan;
        if (drawEggs) {
            foreach (KeyValuePair<Vector2Int, Cell> cellEntry in cells) {
                if (cellEntry.Value.egg) {
                    Gizmos.DrawSphere(grid.GetCellCenterWorld(cellEntry.Key.ToVector3()), 0.2f);
                }
            }
        }
    }
}
