using UnityEngine;
using System.Collections;

public static class TransformDeepChildExtension
{
    //Breadth-first search
    public static Transform FindDeepChild(this Transform aParent, string aName)
    {
        var result = aParent.Find(aName);
        if (result != null)
            return result;
        foreach (Transform child in aParent) {
            result = child.FindDeepChild(aName);
            if (result != null)
                return result;
        }
        return null;
    }


    /*
    //Depth-first search
    public static Transform FindDeepChild(this Transform aParent, string aName)
    {
        foreach(Transform child in aParent)
        {
            if(child.name == aName )
                return child;
            var result = child.FindDeepChild(aName);
            if (result != null)
                return result;
        }
        
        return null;
    }
    */


}

static public class MethodExtensionForMonoBehaviourTransform
{
    /// <summary>
    /// Gets or add a component. Usage example:
    /// BoxCollider boxCollider = transform.GetOrAddComponent<BoxCollider>();
    /// </summary>
    static public T GetOrAddComponent<T>(this Component child) where T : Component
    {
        T result = child.GetComponent<T>();
        if (result == null) {
            result = child.gameObject.AddComponent<T>();
        }
        return result;
    }

    static public Vector3 SetX(this Vector3 vec, float value)
    {
        vec.x = value;
        return vec;
    }
    static public Vector3 SetY(this Vector3 vec, float value)
    {
        vec.y = value;
        return vec;
    }
    static public Vector3 SetZ(this Vector3 vec, float value)
    {
        vec.z = value;
        return vec;
    }

    static public Vector2 ToVector2(this Vector3 vec)
    {
        return new Vector2(vec.x, vec.y);
    }

    static public Vector3 ToVector3(this Vector2 vec) {
        return new Vector3(vec.x, vec.y, 0);
    }

    static public Vector2Int ToVector2(this Vector3Int vec) {
        return new Vector2Int(vec.x, vec.y);
    }

    static public Vector3Int ToVector3(this Vector2Int vec) {
        return new Vector3Int(vec.x, vec.y, 0);
    }
}

public static class ExtensionMethods
{

    public static float Map(this float value, float from1, float to1, float from2, float to2)
    {
        return (value - from1) / (to1 - from1) * (to2 - from2) + from2;
    }

    public static Color SetA(this Color c, float a) {
        return new Color(c.r, c.g, c.b, a);
    }

    public static T Random<T>(this T[] array) {
        return array[UnityEngine.Random.Range(0, array.Length)];
    }
}
